@@ -3,7 +3,7 @@ package YATT::LRXML::MetaInfo;
 use strict;
 use warnings FATAL => qw(all);
 use base qw(YATT::Class::Configurable);
-use Exporter qw(import);
+BEGIN {require Exporter; *import = \&Exporter::import}
 our @EXPORT = qw(MetaInfo);
 our @EXPORT_OK = @EXPORT;
 
